// verify node and npm versions

'use strict';

const check = require('check-node-version');
const chalk = require('chalk');
const config = require('../package.json');
const xl = `${chalk.cyan('[Express Labs]')}: `;

function logXL(message) {
  console.log(xl + message);
}

logXL('Verifying correct version for node and npm...');

if (!config.engines) {
  logXL(chalk.red(`${chalk.bold('FATAL ERROR')} - package.json is missing the engines property.`));

  process.exit(1);
}

check(
  {
    node: config.engines.node,
    npm: config.engines.npm,
  },
  (error, results) => {
    if (error) {
      console.error(error);
      return;
    }

    if (results.isSatisfied) {
      logXL(`${chalk.green('Verified')}\n`);

      return;
    }

    logXL(chalk.red('Some package version(s) failed!'));

    for (const packageName of Object.keys(results.versions)) {
      const pkg = results.versions[packageName];

      if (!pkg.isSatisfied) {
        console.error(
          chalk.red(
            `Wrong version of ${packageName} ${pkg.version.raw} wanted version ${pkg.wanted.raw}`
          )
        );
      }
    }

    process.exitCode = 1;
  }
);
