#!/bin/bash

#Stash current changes
git stash > /dev/null
rc=$?; if [[ $rc != 0 ]]; then echo "failed at stashing changes"; exit $rc; fi

#Go to develop
git checkout develop/v5.x > /dev/null
git pull origin develop/v5.x --tags > /dev/null
rc=$?; if [[ $rc != 0 ]]; then echo "failed at checkout out develop"; exit $rc; fi

#Store the last tag's name
lasttag="$(git describe --tags --abbrev=0)"
rc=$?; if [[ $rc != 0 ]]; then echo "failed at getting last tag name"; exit $rc; fi

echo ""
echo "------RELEVANT COMMITS------"
echo ""

git log --pretty=oneline "${lasttag}..HEAD" | awk '{for (i=2; i<NF; i++) printf $i " "; print $NF}' | grep '#' | xargs -I {} echo '- {}'
rc=$?; if [[ $rc != 0 ]]; then echo "failed at diffing commits between HEAD and last tag"; exit $rc; fi

echo ""
echo "------MAKE A SELECTION------"
echo ""
echo "Press 1 for a patch"
echo "Press 2 for a minor bump"
echo "Press anything else to geeeeeet out of here"
read -n 1 -p "" command
if [ "$command" = "1" ]; then
  echo ""
  nexttag="$(npm version patch)"
elif [ "$command" = "2" ]; then
  echo ""
  nexttag="$(npm version minor)"
else
  exit 0;
fi

git push origin develop/v5.x --tags > /dev/null
open https://github.com/express-labs/app_express.com/releases/new?tag=${nexttag}

echo ""
echo "------INSTRUCTIONS FOR HUMAN------"
echo ""
echo "Copy the commit list and paste it into the release notes, check the 'prerelease' box, and publish. Then go to bamboo and build your new tag."
echo ""
