#!/bin/bash

#Stash current changes
git stash > /dev/null
rc=$?; if [[ $rc != 0 ]]; then echo "failed at stashing changes"; exit $rc; fi

#Go to develop
git checkout develop/v3.x > /dev/null
git pull origin develop/v3.x --tags > /dev/null
rc=$?; if [[ $rc != 0 ]]; then echo "failed at checkout out develop"; exit $rc; fi

#Store the last tag's name
lasttag="$(git describe --tags --abbrev=0)"
rc=$?; if [[ $rc != 0 ]]; then echo "failed at getting last tag name"; exit $rc; fi

#Split tag by the dot
IFS='.' read -ra parts <<< "$lasttag"
rc=$?; if [[ $rc != 0 ]]; then echo "failed at splitting last tag name"; exit $rc; fi

hotfixroot="${parts[0]}.${parts[1]}.${parts[2]}"

#Use the last hotfix to decide what the next tag should be
if [ -z ${parts[3]} ]; then
  #There was no previous hotfix, so this is a .1
  nexttag="${lasttag}.1"
else
  #There was a previous hotfix, so increment the hotfix number
  nexthotfix="$((${parts[3]} + 1))"
  nexttag="${hotfixroot}.${nexthotfix}"
fi

if [[ -z $nexttag ]]; then echo "next tag name is null"; exit 1; fi

#Create a branch for the hotfix
git checkout -b "hotfix/${nexttag}" > /dev/null
rc=$?; if [[ $rc != 0 ]]; then echo "failed at creating hotfix branch"; exit $rc; fi

echo "--------------------"
echo ""

#replace version in package.json and package-lock.json
sed -i '' -e "s/${hotfixroot:1}/${nexttag:1}/g" ./package.json
sed -i '' -e "s/${hotfixroot:1}/${nexttag:1}/g" ./package-lock.json

echo "You are now on a hotfix branch. Package.json and package-lock.json have been updated."
echo "Your branch name is hotfix/${nexttag}"
echo "Your tag name is ${nexttag}"
echo "When you are finished developing, run 'git tag ${nexttag}', push your hotfix branch with the '--tags' flag, and when you merge to develop, use develop's version number (not your hotfix's version number)"

