// Apollo is an enterprise GraphQL module
import { ApolloClient } from 'apollo-client';
import { ApolloLink } from 'apollo-link';
import { HttpLink } from 'apollo-link-http';
import { InMemoryCache } from 'apollo-cache-inmemory';
import { onError } from 'apollo-link-error';
import fetch from 'unfetch'; // eslint-disable-line import/extensions
// this file absolutely exists and is the correct text case (lowercase)
// this must be an issue with how the package was bundled with rollup
// ignoring for now.
/* eslint-disable import/no-unresolved, import/extensions */
import {
  // akamaiCaching,
  hasHeaders,
  isCacheableHeader,
  queryClassificationHeader,
  queryDebug,
  sourceHeader,
  trackGraphQLErrors,
  uid,
} from '@express-labs/raven-middleware';

// GQL operation operation ignore list
const ignoreList = [];

const httpLink = new HttpLink({
  credentials: 'same-origin',
  fetch,
  uri: '/graphql',
});

const middlewares = [
  hasHeaders,
  // akamaiCaching,
  queryClassificationHeader,
  sourceHeader('app_express.com'),
  isCacheableHeader,
  uid,
];

if (window.isDebugMode) middlewares.push(queryDebug);

const client = new ApolloClient({
  link: ApolloLink.from([onError(trackGraphQLErrors(ignoreList)), ...middlewares, httpLink]),
  cache: new InMemoryCache(),
  shouldBatch: true,
});

export default client;
