# debugPropStream

The debugPropsStream higher order component allows you to log any incoming props to the browser's console.  Use this HOC to peek at the shape of data in a chain of higher order components.   If you are developing a new component, you might want to place this before mapProps in a chain of higher order components.  This way you can see the structure of the data and map it to a new, flatter, simpler, structure before handing it to the target component.  You can also use this to examine the shape of a graphql query response object.

## Pseudocode Example
```javascript
// In your component's index.js file...
import { compose } from 'react-apollo';
import {
  mapProps,
  withComponentLoading,
  withInventory,
  withRouter,
  debugPropStream,
} from '../../../../hocs';
import HelloWorld from './HelloWorld';

export compose({
  withRouter,
  withInventory,
  withComponentLoading(),
  debugPropStream('Hello Wold Props Yo!'),
  mapProps({
    mode: 'gate',
    mapFunction: (ownProps) => {
      // dev-ing this part still
      // I'm using debugPropStream to find out the shape of the incoming ownProps.
    }
  })

})(HelloWorld);
```

## Arguments
debugPropStream has a single optional argument.

### label (optional)
You can pass in a string and this will be used as a label for data logged to your browser's console.
