import React from 'react';
import { shallow } from 'enzyme';
import debugPropStreamFactory, { DebugPropStream } from '../debugPropStream';

describe('debugPropStream()', () => {
  const getTestProps = () => ({
    component: jest.fn(),
    label: 'label',
    prop1: 'foo',
    prop2: 'bar',
    prop3: 'bazz'
  });
  const testProps = getTestProps();
  let wrapper;

  beforeEach(() => {
    wrapper = shallow(<DebugPropStream {...testProps} />);
  });
  it('should include the returned object as props passed to the wrapped component', () => {
    const { prop1, prop2, prop3 } = testProps;
    expect(wrapper.props()).toEqual(expect.objectContaining({ prop1, prop2, prop3 }));
  });
  it('returns a function that passes the wrapped component and a config to a higher order function', () => {
    const testComponent = jest.fn();
    const testLabel = 'testLabel';
    expect(debugPropStreamFactory(testLabel)(testComponent)).toEqual(expect.any(Function));
    expect(debugPropStreamFactory(testLabel)(testComponent).displayName).toBe('debugPropStream');
  });
  describe('the higher order function that this function returns', () => {
    const testComponent = jest.fn();
    const testLabel = 'testLabel';
    const hoc = debugPropStreamFactory(testLabel)(testComponent)({ fakeProps: true });

    it('should pass the arguments as props to the MapProps component', () => {
      expect(hoc.props).toEqual({
        component: testComponent,
        fakeProps: true,
        label: testLabel
      });
    });
  });
});
