# errorBoundary

The errorBoundary higher order component allows you to log a component runtime error to the logClientError Raven-Server endpoint (logs viewable in the "raven-alerts" private channel in Slack).  Use this HOC for better peace of mind that in the case of a runtime caused by a component, said component will default to a "Something went wrong here" view while allowing remaining code on the page to be executed. This is not a "do all, save all" component. However, it will help maintain the integrity of the application while alerting an error log for further investigation.  If you are developing a new component, you might want to place this first in a chain of higher order components as a safety fallback.

## General Notes

- You must invoke the HOC whether or not you pass a config object

## Log Details

Each log will include the following:

- Priority level (defaults to 'N/A' if not used)
- Name of compromised component
- Location of compromised component
- Stacktrace

## Pseudocode Example

```javascript
// In your component's index.js file...
import { compose } from 'react-apollo';
import {
  mapProps,
  withComponentLoading,
  withInventory,
  withRouter,
  errorBoundary,
} from '../../../../hocs';
import HelloWorld from './HelloWorld';

export compose({
  errorBoundary({
    priority: '1',
  }),
  withRouter,
  withInventory,
  withComponentLoading(),
})(HelloWorld);
```

## Arguments

errorBoundary can be passed an optional config object and has two properties available for further customization.

### priority (optional)

You can pass in a string and this will be displayed in the user log in the case of a component catching an error.

### errorView (optional)

You can pass in a node (string, JSX, etc.) and this will be displayed in the web application's UI in the case of an error being caught.
