/* eslint-disable */
import React from 'react';
import PropTypes from 'prop-types';
import { graphql } from 'react-apollo';
import gql from 'graphql-tag';
import s from './errorBoundary.module.scss';

export class ErrorBoundary extends React.Component {
  static meta = {
    VERSION: '1.0.0',
  };

  static propTypes = {
    component: PropTypes.func.isRequired,
    errorView: PropTypes.node.isRequired,
    logClientError: PropTypes.func.isRequired,
    priority: PropTypes.string.isRequired,
  };

  constructor(props) {
    super(props);
    this.state = {
      hasError: false,
    };
    this.logError = this.logError.bind(this);
  }

  componentDidCatch(error, info) {
    // display fallback UI
    this.setState({ hasError: true });
    // log the error to an error reporting service
    this.logError(this.errorDetails(info.componentStack));
  }

  errorDetails(body) {
    const title = `

    The *<ErrorBoundary />* component has caught an error. See details:


        *Priority*:   \`${this.props.priority}\`

        *Component*: \`<${body.match(/[^in\s][a-zA-Z]+[^\s]/)[0]} />\`

        *Location*: ${window.location.href}


    `;

    return { body, title };
  }

  logError({ title: message, body: details }) {
    if (!this.props.logClientError) return;

    this.props.logClientError({ message, details });
  }

  render() {
    if (this.state.hasError) {
      return this.props.errorView;
    }

    const { component: WrappedComponent } = this.props;
    const newProps = {
      ...this.props,
      logClientError: this.logError,
    };

    return <WrappedComponent {...newProps} />;
  }
}

const ConnectedErrorBoundary = graphql(
  gql`
    mutation logClientError($message: String!, $details: String) {
      logClientError(message: $message, details: $details) {
        success
      }
    }
  `,
  {
    props({ mutate }) {
      return {
        logClientError({ message, details }) {
          return mutate({
            variables: { message, details },
          });
        },
      };
    },
  },
)(ErrorBoundary);

function errorBoundary(WrappedComponent, config) {
  const {
    priority = 'N/A',
    errorView = <h1 className={s.title}>Something went wrong here</h1>,
  } = config;
  const hoc = props => (
    <ConnectedErrorBoundary
      {...props}
      priority={priority}
      errorView={errorView}
      component={WrappedComponent}
    />
  );

  hoc.displayName = 'errorBoundary';
  return hoc;
}

function errorBoundaryFactory() {
  return (config = {}) => Component => errorBoundary(Component, config);
}

export default errorBoundaryFactory();
/* eslint-enable */
