import 'react-app-polyfill/ie11';
import React from 'react';
import ReactDOM from 'react-dom';
import throttle from 'lodash.throttle';
import { ApolloProvider } from 'react-apollo';
import { Brander } from '@express-labs/raven-ui';
import { Provider } from 'react-redux';
import * as serviceWorker from './serviceWorker';

// Application state modules and helpers
import client from './appState/ravenApolloClient';
import ravenConfigureStore from './appState/ravenConfigureStore';
import rootReducer from './appState/ravenRootReducer';
import { updateDimensions, updateScrollTop } from './appState/ducks/deviceWidth';

// load all the routes and route related listeners and mutators for our app
// if it does routes... you'll find it here.
import Router from './routes';

// React-axe
// Tests the app with the axe-core accessibility testing library
// Results are shown in the Chrome DevTools console
if (process.env.NODE_ENV !== 'production') {
  // eslint-disable-next-line import/no-extraneous-dependencies
  const axe = require('react-axe');
  axe(React, ReactDOM, 1000);
}

// create a redux store to store application state
const store = ravenConfigureStore(rootReducer);

// Track window dimensions and add them to our redux store
const trackWindowDimensions = throttle(
  () => window.requestAnimationFrame(() => store.dispatch(updateDimensions())),
  400,
);
window.addEventListener('resize', trackWindowDimensions, false);

// Track scrollTop in redux store
const trackScrollTop = throttle(
  () => window.requestAnimationFrame(() => store.dispatch(updateScrollTop())),
  400,
);
window.addEventListener('scroll', trackScrollTop, false);

ReactDOM.render(
  <ApolloProvider client={client}>
    <Provider store={store}>
      <Brander>
        <Router />
      </Brander>
    </Provider>
  </ApolloProvider>,
  document.getElementById('root'),
);

// ReactDOM.render(<Router />, document.getElementById('root'));

// If you want your app to work offline and load faster, you can change
// unregister() to register() below. Note this comes with some pitfalls.
// Learn more about service workers: http://bit.ly/CRA-PWA
serviceWorker.unregister();
